@@ -1,4 +1,3 @@
-// -*- c++ -*-
 /* Copyright 2002, The libsigc++ Development Team
  *  Assigned to public domain.  Use as you wish without restriction.
  */
@@ -12,7 +11,6 @@
 //The Tru64 compiler seems to need this to avoid an unresolved symbol
 //See bug #161503
 #include <new>
-SIGC_USING_STD(new)
 
 namespace
 {
@@ -42,7 +40,7 @@ public:
 
 int main(int argc, char* argv[])
 {
-  TestUtilities* util = TestUtilities::get_instance();
+  auto util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
